/*
 * This file is part of the ESPDA Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*
 * $Id: espda_param.h 161538 2014-05-22 13:56:10Z gcupani $
 * $Author: gcupani $
 * $Date: 2014-05-22 15:56:10 +0200 (Thu, 22 May 2014) $
 * $Revision: 161538 $
 */

#ifndef ESPDA_PARAM_H
#define ESPDA_PARAM_H

/*-----------------------------------------------------------------------------
                                   Includes
 -----------------------------------------------------------------------------*/

#include <cpl.h>

#include "espda_dfs.h"
#include "espda_print.h"

/*-----------------------------------------------------------------------------
                                   Defines
 -----------------------------------------------------------------------------*/

#define COADD_SPEC_REJ_FLAG "espda.espda_coadd_spec.rej_flag"
#define COADD_SPEC_AIR_FLAG "espda.espda_coadd_spec.air_flag"
#define COADD_SPEC_REBIN_FLAG "espda.espda_coadd_spec.rebin_flag"
#define COADD_SPEC_EQUAL_FLAG "espda.espda_coadd_spec.equal_flag"
#define COADD_SPEC_EQUAL_REF "espda.espda_coadd_spec.equal_ref"
#define COADD_SPEC_KAPPA "espda.espda_coadd_spec.kappa"
#define COADD_SPEC_WAVEL_MIN "espda.espda_coadd_spec.wavel_min"
#define COADD_SPEC_WAVEL_MAX "espda.espda_coadd_spec.wavel_max"
#define COADD_SPEC_VEL_STEP "espda.espda_coadd_spec.vel_step"
#define COADD_SPEC_MODEL_RESOL "espda.espda_coadd_spec.model_resol"
#define COADD_SPEC_RV "espda.espda_coadd_spec.rv"
#define COADD_SPEC_ZEM "espda.espda_coadd_spec.zem"
#define COADD_SPEC_ADP_COLUMNS "espda.espda_coadd_spec.adp_columns"

#define MASK_SPEC_MASK_LIMIT "espda.espda_mask_spec.mask_limit"

#define IDEN_SYST_VIS_REJ "espda.espda_iden_syst.vis_rej"

#define FIT_LINE_ADD "espda.espda_fit_line.add"
#define FIT_LINE_EDIT_FILE "espda.espda_fit_line.edit_file"
#define FIT_LINE_FIT_FLAG "espda.espda_fit_line.fit_flag"
#define FIT_LINE_GRP_SEL "espda.espda_fit_line.grp_sel"
#define FIT_LINE_HWIDTH "espda.espda_fit_line.hwidth"
#define FIT_LINE_ITER_MAX "espda.espda_fit_line.iter_max"
#define FIT_LINE_MODEL_RESOL "espda.espda_fit_line.model_resol"
#define FIT_LINE_PAR_RANGE "espda.espda_fit_line.par_range"


#define espda_param_adjust2(VALUE, MIN, MAX, ALIAS, FORMAT) { \
            if (VALUE < MIN) { \
                espda_print_verb(1, cpl_msg_warning(cpl_func, "%s=" #FORMAT \
                    " is too low:  changed to %s=" #FORMAT ".", ALIAS, VALUE, \
                    ALIAS, MIN)); \
                VALUE = MIN; \
            } \
            if (VALUE > MAX) { \
                espda_print_verb(1, cpl_msg_warning(cpl_func, "%s=" #FORMAT \
                    " is too high. changed to %s=" #FORMAT ".", ALIAS, VALUE, \
                    ALIAS, MAX)); \
                VALUE = MAX; \
            } \
        } \

#define espda_param_bool(A, B, C)                       \
            cpl_msg_info(cpl_func, "Loading %s...", A); \
            int B = cpl_parameter_get_bool(C);          \

#define espda_param_double(A, B, C, D, E)                  \
            cpl_msg_info(cpl_func, "Loading %s...", A);    \
            double B = espda_param_adjust(CPL_TYPE_DOUBLE, \
                       cpl_parameter_get_double(C), D, E); \

#define espda_param_int(A, B, C, D, E)                       \
            cpl_msg_info(cpl_func, "Loading %s...", A);      \
            int B = (int)espda_param_adjust(CPL_TYPE_INT,    \
                    (double)cpl_parameter_get_int(C), D, E); \

#define espda_param_string(A, B, C)                      \
            cpl_msg_info(cpl_func, "Loading %s...", A);  \
            const char *B = cpl_parameter_get_string(C); \

/*-----------------------------------------------------------------------------
                                       Prototypes
 -----------------------------------------------------------------------------*/

double          espda_param_adjust (cpl_type,
                                    double,
                                    double,
                                    double);

cpl_array      *espda_param_extract(const char *,//[LEN_STRING],
                                    char       *,
                                    cpl_size,
                                    cpl_size,
                                    cpl_type);

cpl_error_code  espda_param_load   (const cpl_parameterlist *,
                                    const char      *,
                                    ...);

cpl_error_code  espda_param_replace(const char *,
                                    char       *,
                                    char       *,
                                    char       *);//[LEN_STRING]);

#endif
