/* 
 * This file is part of the ESPDA Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*
 * $Id: espda_rhk.h 161769 2014-05-30 14:32:34Z gcupani $
 * $Author: gcupani $
 * $Date: 2014-05-30 16:32:34 +0200 (Fri, 30 May 2014) $
 * $Revision: 161769 $
 */

#ifndef ESPDA_RHK_H
#define ESPDA_RHK_H

/*-----------------------------------------------------------------------------
                                   Includes
 -----------------------------------------------------------------------------*/

#include <cpl.h>
#include <math.h>

/*-----------------------------------------------------------------------------
                                   Defines
 -----------------------------------------------------------------------------*/

#define CENTRAL_WAVELENGTH_K 3933.664
#define START_WAVELENGTH_K 3932.574
#define END_WAVELENGTH_K 3934.754
#define WIDTH_K 1.09

#define CENTRAL_WAVELENGTH_H 3968.470
#define START_WAVELENGTH_H 3967.380
#define END_WAVELENGTH_H 3969.560
#define WIDTH_H 1.09

#define START_WAVELENGTH_V 3891.07
#define END_WAVELENGTH_V 3911.07

#define START_WAVELENGTH_R 3991.07
#define END_WAVELENGTH_R 4011.07

//#define CA_II_ALPHA 1.111
//#define CA_II_BETA 0.0153
#define SPEED_OF_LIGHT 2.99792458e5

/*----------------------------------------------------------------------------
 Data structures
 ----------------------------------------------------------------------------*/

/*-----------------------------------------------------------------------------
                                   Functions prototypes
 -----------------------------------------------------------------------------*/

cpl_error_code espda_correct_rhk_blaze(cpl_image *,
				   cpl_image *,
				   cpl_image *,
				   cpl_image *,
				   cpl_image **,
				   cpl_image **,
				   cpl_image **);

cpl_error_code espda_measure_flux(double *,
                                  double *,
                                  double *,
                                  double,
                                  double,	
                                  int *,
                                  int ,
                                  double *,
                                  double *);

cpl_error_code espda_compu_rhk_index(double,
                                     double,
                                     double,
                                     double *,
                                     double *);

cpl_error_code espda_compu_prot_age(double,
                                    double,
                                    double,
                                    double *,
                                    double *,
                                    double *,
                                    double *);

cpl_error_code espda_measure_flux_HK(double *wavelength,
                                  double *flux,
                                  double *error,
                                  double,
                                  double,	
                                  double,
                                  double,	
                                  int *quality,
                                  int S1D_length,
                                  double *pbflux,
                                  double *pbflux_err);

#endif
